==> nextcloud-23.0.5.tgz: nextcloud/apps/files_sharing/l10n/lv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Koplietots ar jums",
    "Nothing shared with you yet" : "Nekas vēl nav koplietots",
    "Files and folders others share with you will show up here" : "Šeit būs redzamas koplietotās datnes un mapes, ko citi koplietos ar jums",
    "Shared with others" : "Koplietots ar citiem",
    "Nothing shared yet" : "Nekas vēl nav koplietots",
    "Files and folders you share will show up here" : "Šeit būs redzamas jūsu koplietotās datnes un mapes",
    "Shared by link" : "Koplietots ar saiti",
    "No shared links" : "Nav koplietotu saišu",
    "Files and folders you share by link will show up here" : "Šeit būs redzamas ar saiti koplietotās datnes un mapes",
    "Deleted shares" : "Dzēstie koplietojumi",
    "No deleted shares" : "Nav dzēstu koplietojumu",
    "Shares you deleted will show up here" : "Šeit būs redzami jūsu dzēstie koplietojumi",
    "Pending shares" : "Gaidošie koplietojumi",
    "No pending shares" : "Nav gaidošie koplietojumi",
    "Shares you have received but not confirmed will show up here" : "Šeit tiks rādīti jūsu saņemtie, bet neapstiprinātie koplietojumi",
    "Shares" : "Koplietots",
    "No shares" : "Nav koplietojumu",
    "Shares will show up here" : "Šeit tiks rādīti koplietojumi",
    "Restore" : "Atjaunot",
    "Restore share" : "Atjaunot koplietojumu",
    "Something happened. Unable to restore the share." : "Kaut kas atgadījās. Nevar atjaunot kopīgošanu.",
    "Accept share" : "Pieņemt koplietojumu",
    "Something happened. Unable to accept the share." : "Kaut kas atgadījās. Nevar apstiprināt koplietošanu.",
    "Reject share" : "Noraidīt koplietojumu",
    "Something happened. Unable to reject the share." : "Kaut kas atgadījās. Nevar noraidīt koplietojumu.",
    "Waiting…" : "Gaida...",
    "error" : "kļūda",
    "finished" : "pabeigts",
    "This will stop your current uploads." : "Tādējādi tiks pārtraukta jūsu pašreizējā augšupielāde.",
    "Move or copy" : "Pārvietot vai kopēt",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "You can upload into this folder" : "Jūs variet augšuplādēt šajā mapē",
    "Terms of service" : "Pakalpojuma noteikumi",
    "No compatible server found at {remote}" : "Nav atrasts neviens saderīgs serveris {remote}",
    "Invalid server URL" : "Nederīgs servera url",
    "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti jūsu Nextcloud",
    "No expiration date set" : "Nav noteikts derīguma termiņa beigu datums",
    "Shared by" : "Koplietoja",
    "File shares" : "Datņu koplietojumi",
    "Downloaded via public link" : "Lejupielādēt izmantojot publisku saiti",
    "Downloaded by {email}" : "Lejupielādēts {email}",
    "{file} downloaded via public link" : "{file} lejupielādēts izmantojot publisku saiti",
    "{email} downloaded {file}" : "{email} lejupielādēts {file}",
    "Shared with group {group}" : "Koplietots ar grupu {group}",
    "Removed share for group {group}" : "Noņēma koplietošanu grupai {group}",
    "{actor} shared with group {group}" : "{actor} koplietoja ar grupu {group}",
    "{actor} removed share for group {group}" : "{actor} noņēma koplietošanu grupai {group}",
    "Share for group {group} expired" : "Kopīgošana grupai {group} ir beigusies",
    "You shared {file} with group {group}" : "Jūs koplietojāt {file} ar grupu {group}",
    "You removed group {group} from {file}" : "Jūs noņēmāt grupu {group} no {file}",
    "{actor} shared {file} with group {group}" : "{actor} koplietoja {file} ar grupu {group}",
    "{actor} removed group {group} from {file}" : "{actor} noņēma grupu {group} no {file}",
    "Share for file {file} with group {group} expired" : "Datnes {file} kopīgošana ar grupu {group} ir beigusies",
    "Shared as public link" : "Koplietots kā publiska saite",
    "Removed public link" : "Noņemta publiska saite",
    "Public link expired" : "Publiskā saite ir beigusies",
    "{actor} shared as public link" : "{actor} koplietoja kā publisku saiti",
    "{actor} removed public link" : "{actor} noņēma publisko saiti",
    "Public link of {actor} expired" : "{actor} publiskā saite beidzās",
    "You shared {file} as public link" : "Jūs koplietojāt {file} kā publisku saiti",
    "You removed public link for {file}" : "Jūs noņēmāt {file} publisko saiti",
    "Public link expired for {file}" : "{file} publiskā saite beidzās",
    "{actor} shared {file} as public link" : "{actor} koplietoja {file} kā publisko saiti",
    "{actor} removed public link for {file}" : "{actor} noņēma {file} publisko saiti",
    "Public link of {actor} for {file} expired" : "{actor} publiskā saite {file} beidzās",
    "{user} accepted the remote share" : "{user} apstiprināja attālo koplietošanu",
    "{user} declined the remote share" : "{user} noraidīja attālo koplietošanu",
    "You received a new remote share {file} from {user}" : "Jūs saņēmāt attālo {file} koplietošanu no {user}",
    "{user} accepted the remote share of {file}" : "{user} apstiprināja {file} attālo koplietošanu",
    "{user} declined the remote share of {file}" : "{user} noraidīja {file} attālo koplietošanu",
    "{user} unshared {file} from you" : "{user} noņēma {file} koplietošanu ar jums",
    "Shared with {user}" : "Koplietoja ar {user}",
    "Removed share for {user}" : "Noņēma koplietošanu ar {user}",
    "You removed yourself" : "Jūs noņēmāt sevi",
    "{actor} removed themselves" : "{actor} noņēma sevi",
    "{actor} shared with {user}" : "{actor} koplietoja ar {user}",
    "{actor} removed share for {user}" : "{actor} noņēma koplietošanu {user}",
    "Shared by {actor}" : "Koplietoja {actor}",
    "{actor} removed share" : "{actor} noņēma koplietošanu",
    "Share for {user} expired" : "Koplietošana {user} beidzās",
    "Share expired" : "Koplietošana beidzās",
    "You shared {file} with {user}" : "Jūs koplietojāt {file} ar {user}",
    "You removed {user} from {file}" : "Jūs noņēmāt koplietošanu {user} no {file}",
    "You removed yourself from {file}" : "Jūs noņēmāt sevi no {file}",
    "{actor} removed themselves from {file}" : "{actor} noņēma sevi no {file}",
    "{actor} shared {file} with {user}" : "{actor} koplietoja {file} ar {user}",
    "{actor} removed {user} from {file}" : "{actor} noņemts {user} no {file}",
    "{actor} shared {file} with you" : "{actor} koplietoja {file} ar jums",
    "{actor} removed you from the share named {file}" : "{actor} noņēma jūs ko koplietošanas ar nosaukumu {file}",
    "Share for file {file} with {user} expired" : "Koplietošana datnei {file} ar {user} beidzās",
    "Share for file {file} expired" : "Koplietošana datnei {file} beidzās",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "E-pastā vai saitē koplietotā datne vai mape tika <strong>lejupielādēta</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Datne vai mape tika koplietota no <strong>cita servera</strong>",
    "Files" : "Datnes",
    "A file or folder has been <strong>shared</strong>" : "<strong>Koplietota</strong> datne vai mape",
    "Shared link" : "Koplietota saite",
    "Wrong share ID, share doesn't exist" : "Nepareizs koplietošanas ID, koplietotne neeksistē",
    "Could not delete share" : "Neizdevās dzēst koplietotni",
    "Please specify a file or folder path" : "Lūdzu norādiet datnes vai mapes ceļu",
    "Could not create share" : "Nevar izveidot koplietošanu",
    "Please specify a valid user" : "Lūdzu norādiet derīgu lietotāju",
    "Group sharing is disabled by the administrator" : "Administrators grupas koplietošanu ir atslēdzis",
    "Please specify a valid group" : "Lūdzu norādiet derīgu grupu",
    "Public link sharing is disabled by the administrator" : "Administrators publisku saites koplietošanu ir atslēdzis",
    "Public upload disabled by the administrator" : "Administrators publisku augšupielādi ir atslēdzis",
    "Public upload is only possible for publicly shared folders" : "Publiska augšupielāde iespējama tikai publiski koplietotām mapēm",
    "Invalid date, date format must be YYYY-MM-DD" : "Nepareizs datums, datumam jābūt YYYY-MM-DD formātā",
    "Unknown share type" : "Nezināms koplietošanas tips",
    "Not a directory" : "Nav direktorijs",
    "Could not lock node" : "Nevarēja bloķēt",
    "Could not lock path" : "Nevarēja bloķēt ceļu",
    "Wrong or no update parameter given" : "Nepareizs atjaunināšanas parametrs vai tas nav norādīts",
    "shared by %s" : "Koplietoja %s",
    "Download all files" : "Lejupielādēt visas datnes",
    "Direct link" : "Tiešā saite",
    "Share API is disabled" : "Koplietošanas API ir atslēgta",
    "File sharing" : "Datņu koplietošana",
    "Share will expire tomorrow" : "Koplietošana rīt beigsies",
    "One or more of your shares will expire tomorrow" : "Vienam vai vairākiem jūsu koplietojumiem rīt beigsies termiņš",
    "Your share of {node} will expire tomorrow" : "Jūsu koplietotajam {node} rīt beigsies termiņš",
    "You received {share} as a share by {user}" : "Jūs saņēmāt koplietotu {share} no {user}",
    "You received {share} to group {group} as a share by {user}" : "Jūs saņēmāt koplietotu {share} grupai {group} no {user}",
    "Accept" : "Pieņemt",
    "Reject" : "Noraidīt",
    "Sharing" : "Koplietošana",
    "Accept user and group shares by default" : "Pēc noklusējuma pieņemt koplietošanu no lietotājiem un grupām",
    "Reset" : "Atiestatīt",
    "Unknown error" : "Nezināma kļūda",
    "Allow editing" : "Atļaut rediģēšanu",
    "Read only" : "Tikai lasāms",
    "Allow upload and editing" : "Atļaut augšupielādi un rediģēšanu",
    "File drop (upload only)" : "Datņu mešana (tikai augšupielādei)",
    "Read" : "Lasīt",
    "Upload" : "Augšupielādēt",
    "Edit" : "Rediģēt",
    "Allow creating" : "Atļaut veidošanu",
    "Allow deleting" : "Atļaut dzēšanu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Expiration date enforced" : "Piespiedu derīguma termiņš",
    "Set expiration date" : "Uzstādīt beigu termiņu",
    "Enter a date" : "Ievadiet datumu",
    "Note to recipient" : "Piezīme saņēmējam",
    "Unshare" : "Pārtraukt koplietošanu",
    "group" : "grupa",
    "conversation" : "saruna",
    "remote" : "attālināti",
    "remote group" : "attālinātā grupa",
    "guest" : "viesis",
    "Link copied" : "Saite nokopēta",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Only works for users with access to this file" : "Darbojas tikai lietotājiem, kuriem ir piekļuve šai datnei",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Cancel" : "Atcelt",
    "Hide download" : "Slēpt lejupielādi",
    "Password protect" : "Aizsargāt ar paroli",
    "Video verification" : "Video verifikācija",
    "Add another link" : "Pievienot citu saiti",
    "Share link" : "Koplietot saiti",
    "Resharing is not allowed" : "Atkārtota koplietošana nav atļauta",
    "Name or email …" : "Vārds vai e-pasts ...",
    "Name, email, or Federated Cloud ID …" : "Vārds, e-pasts vai federatīvā mākoņa ID ...",
    "Searching …" : "Meklē...",
    "No elements found." : "Elementi netika atrasti.",
    "Search globally" : "Meklēt globāli",
    "on {server}" : "uz {server}",
    "Others with access" : "Citi ar pieeju",
    "No other users with access found" : "Nav atrasti citi lietotāji ar pieeju",
    "Expires {relativetime}" : "Termiņš beidzas {relativetime}",
    "this share just expired." : "šai koplietošanai tikko beidzās termiņš.",
    "Shared with you by {owner}" : "{owner} koplietoja ar jums",
    "Link to a file" : "Datnes saite",
    "Shared" : "Koplietots",
    "Share" : "Koplietot",
    "Shared with" : "Koplietots ar",
    "Shared with you and the group {group} by {owner}" : "{owner} koplietoja ar jums un grupu {group}",
    "Shared with you and {circle} by {owner}" : "{owner} koplietoja ar jums un {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} koplietoja ar jums un sarunu {conversation}",
    "Shared with you in a conversation by {owner}" : " {owner} koplietoja ar jums sarunā",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Nosaukums",
    "Share time" : "Koplietošanas laiks",
    "Expiration date" : "Termiņa datums",
    "Sorry, this link doesn’t seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the item was removed" : "vienums tika dzēsts",
    "the link expired" : "saitei beidzies termiņš",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more info, please ask the person who sent this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Share note" : "Koplietot piezīmi",
    "Toggle grid view" : "Pārslēgt režģa skatu",
    "Upload files to %s" : "Augšupielādēt datnes uz %s",
    "Note" : "Piezīme",
    "Select or drop files" : "Izvēlies vai ievelc datnes",
    "Uploading files" : "Augšupielādē datnes",
    "Uploaded files:" : "Augšupielādētas datnes:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Veicot datņu augšupielādi, jūs piekrītat %1$spakalpojuma noteikumiem%2$s.",
    "Add to your Nextcloud" : "Pievienot savam Nextcloud",
    "Wrong path, file/folder doesn't exist" : "Nepareizs ceļš, datne/mape neeksistē"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-23.0.7.tgz: nextcloud/apps/files_sharing/l10n/lv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Koplietots ar jums",
    "Nothing shared with you yet" : "Nekas vēl nav koplietots",
    "Files and folders others share with you will show up here" : "Šeit būs redzamas koplietotās datnes un mapes, ko citi koplietos ar jums",
    "Shared with others" : "Koplietots ar citiem",
    "Nothing shared yet" : "Nekas vēl nav koplietots",
    "Files and folders you share will show up here" : "Šeit būs redzamas jūsu koplietotās datnes un mapes",
    "Shared by link" : "Koplietots ar saiti",
    "No shared links" : "Nav koplietotu saišu",
    "Files and folders you share by link will show up here" : "Šeit būs redzamas ar saiti koplietotās datnes un mapes",
    "Deleted shares" : "Dzēstie koplietojumi",
    "No deleted shares" : "Nav dzēstu koplietojumu",
    "Shares you deleted will show up here" : "Šeit būs redzami jūsu dzēstie koplietojumi",
    "Pending shares" : "Gaidošie koplietojumi",
    "No pending shares" : "Nav gaidošie koplietojumi",
    "Shares you have received but not confirmed will show up here" : "Šeit tiks rādīti jūsu saņemtie, bet neapstiprinātie koplietojumi",
    "Shares" : "Koplietots",
    "No shares" : "Nav koplietojumu",
    "Shares will show up here" : "Šeit tiks rādīti koplietojumi",
    "Restore" : "Atjaunot",
    "Restore share" : "Atjaunot koplietojumu",
    "Something happened. Unable to restore the share." : "Kaut kas atgadījās. Nevar atjaunot kopīgošanu.",
    "Accept share" : "Pieņemt koplietojumu",
    "Something happened. Unable to accept the share." : "Kaut kas atgadījās. Nevar apstiprināt koplietošanu.",
    "Reject share" : "Noraidīt koplietojumu",
    "Something happened. Unable to reject the share." : "Kaut kas atgadījās. Nevar noraidīt koplietojumu.",
    "Waiting…" : "Gaida...",
    "error" : "kļūda",
    "finished" : "pabeigts",
    "This will stop your current uploads." : "Tādējādi tiks pārtraukta jūsu pašreizējā augšupielāde.",
    "Move or copy" : "Pārvietot vai kopēt",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "You can upload into this folder" : "Jūs variet augšuplādēt šajā mapē",
    "Terms of service" : "Pakalpojuma noteikumi",
    "No compatible server found at {remote}" : "Nav atrasts neviens saderīgs serveris {remote}",
    "Invalid server URL" : "Nederīgs servera url",
    "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti jūsu Nextcloud",
    "No expiration date set" : "Nav noteikts derīguma termiņa beigu datums",
    "Shared by" : "Koplietoja",
    "File shares" : "Datņu koplietojumi",
    "Downloaded via public link" : "Lejupielādēt izmantojot publisku saiti",
    "Downloaded by {email}" : "Lejupielādēts {email}",
    "{file} downloaded via public link" : "{file} lejupielādēts izmantojot publisku saiti",
    "{email} downloaded {file}" : "{email} lejupielādēts {file}",
    "Shared with group {group}" : "Koplietots ar grupu {group}",
    "Removed share for group {group}" : "Noņēma koplietošanu grupai {group}",
    "{actor} shared with group {group}" : "{actor} koplietoja ar grupu {group}",
    "{actor} removed share for group {group}" : "{actor} noņēma koplietošanu grupai {group}",
    "Share for group {group} expired" : "Kopīgošana grupai {group} ir beigusies",
    "You shared {file} with group {group}" : "Jūs koplietojāt {file} ar grupu {group}",
    "You removed group {group} from {file}" : "Jūs noņēmāt grupu {group} no {file}",
    "{actor} shared {file} with group {group}" : "{actor} koplietoja {file} ar grupu {group}",
    "{actor} removed group {group} from {file}" : "{actor} noņēma grupu {group} no {file}",
    "Share for file {file} with group {group} expired" : "Datnes {file} kopīgošana ar grupu {group} ir beigusies",
    "Shared as public link" : "Koplietots kā publiska saite",
    "Removed public link" : "Noņemta publiska saite",
    "Public link expired" : "Publiskā saite ir beigusies",
    "{actor} shared as public link" : "{actor} koplietoja kā publisku saiti",
    "{actor} removed public link" : "{actor} noņēma publisko saiti",
    "Public link of {actor} expired" : "{actor} publiskā saite beidzās",
    "You shared {file} as public link" : "Jūs koplietojāt {file} kā publisku saiti",
    "You removed public link for {file}" : "Jūs noņēmāt {file} publisko saiti",
    "Public link expired for {file}" : "{file} publiskā saite beidzās",
    "{actor} shared {file} as public link" : "{actor} koplietoja {file} kā publisko saiti",
    "{actor} removed public link for {file}" : "{actor} noņēma {file} publisko saiti",
    "Public link of {actor} for {file} expired" : "{actor} publiskā saite {file} beidzās",
    "{user} accepted the remote share" : "{user} apstiprināja attālo koplietošanu",
    "{user} declined the remote share" : "{user} noraidīja attālo koplietošanu",
    "You received a new remote share {file} from {user}" : "Jūs saņēmāt attālo {file} koplietošanu no {user}",
    "{user} accepted the remote share of {file}" : "{user} apstiprināja {file} attālo koplietošanu",
    "{user} declined the remote share of {file}" : "{user} noraidīja {file} attālo koplietošanu",
    "{user} unshared {file} from you" : "{user} noņēma {file} koplietošanu ar jums",
    "Shared with {user}" : "Koplietoja ar {user}",
    "Removed share for {user}" : "Noņēma koplietošanu ar {user}",
    "You removed yourself" : "Jūs noņēmāt sevi",
    "{actor} removed themselves" : "{actor} noņēma sevi",
    "{actor} shared with {user}" : "{actor} koplietoja ar {user}",
    "{actor} removed share for {user}" : "{actor} noņēma koplietošanu {user}",
    "Shared by {actor}" : "Koplietoja {actor}",
    "{actor} removed share" : "{actor} noņēma koplietošanu",
    "Share for {user} expired" : "Koplietošana {user} beidzās",
    "Share expired" : "Koplietošana beidzās",
    "You shared {file} with {user}" : "Jūs koplietojāt {file} ar {user}",
    "You removed {user} from {file}" : "Jūs noņēmāt koplietošanu {user} no {file}",
    "You removed yourself from {file}" : "Jūs noņēmāt sevi no {file}",
    "{actor} removed themselves from {file}" : "{actor} noņēma sevi no {file}",
    "{actor} shared {file} with {user}" : "{actor} koplietoja {file} ar {user}",
    "{actor} removed {user} from {file}" : "{actor} noņemts {user} no {file}",
    "{actor} shared {file} with you" : "{actor} koplietoja {file} ar jums",
    "{actor} removed you from the share named {file}" : "{actor} noņēma jūs ko koplietošanas ar nosaukumu {file}",
    "Share for file {file} with {user} expired" : "Koplietošana datnei {file} ar {user} beidzās",
    "Share for file {file} expired" : "Koplietošana datnei {file} beidzās",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "E-pastā vai saitē koplietotā datne vai mape tika <strong>lejupielādēta</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Datne vai mape tika koplietota no <strong>cita servera</strong>",
    "Files" : "Datnes",
    "A file or folder has been <strong>shared</strong>" : "<strong>Koplietota</strong> datne vai mape",
    "Shared link" : "Koplietota saite",
    "Could not delete share" : "Neizdevās dzēst koplietotni",
    "Please specify a file or folder path" : "Lūdzu norādiet datnes vai mapes ceļu",
    "Could not create share" : "Nevar izveidot koplietošanu",
    "Please specify a valid user" : "Lūdzu norādiet derīgu lietotāju",
    "Group sharing is disabled by the administrator" : "Administrators grupas koplietošanu ir atslēdzis",
    "Please specify a valid group" : "Lūdzu norādiet derīgu grupu",
    "Public link sharing is disabled by the administrator" : "Administrators publisku saites koplietošanu ir atslēdzis",
    "Public upload disabled by the administrator" : "Administrators publisku augšupielādi ir atslēdzis",
    "Public upload is only possible for publicly shared folders" : "Publiska augšupielāde iespējama tikai publiski koplietotām mapēm",
    "Invalid date, date format must be YYYY-MM-DD" : "Nepareizs datums, datumam jābūt YYYY-MM-DD formātā",
    "Unknown share type" : "Nezināms koplietošanas tips",
    "Not a directory" : "Nav direktorijs",
    "Could not lock node" : "Nevarēja bloķēt",
    "Could not lock path" : "Nevarēja bloķēt ceļu",
    "Wrong or no update parameter given" : "Nepareizs atjaunināšanas parametrs vai tas nav norādīts",
    "shared by %s" : "Koplietoja %s",
    "Download all files" : "Lejupielādēt visas datnes",
    "Direct link" : "Tiešā saite",
    "Share API is disabled" : "Koplietošanas API ir atslēgta",
    "File sharing" : "Datņu koplietošana",
    "Share will expire tomorrow" : "Koplietošana rīt beigsies",
    "One or more of your shares will expire tomorrow" : "Vienam vai vairākiem jūsu koplietojumiem rīt beigsies termiņš",
    "Your share of {node} will expire tomorrow" : "Jūsu koplietotajam {node} rīt beigsies termiņš",
    "You received {share} as a share by {user}" : "Jūs saņēmāt koplietotu {share} no {user}",
    "You received {share} to group {group} as a share by {user}" : "Jūs saņēmāt koplietotu {share} grupai {group} no {user}",
    "Accept" : "Pieņemt",
    "Reject" : "Noraidīt",
    "Sharing" : "Koplietošana",
    "Accept user and group shares by default" : "Pēc noklusējuma pieņemt koplietošanu no lietotājiem un grupām",
    "Reset" : "Atiestatīt",
    "Unknown error" : "Nezināma kļūda",
    "Allow editing" : "Atļaut rediģēšanu",
    "Read only" : "Tikai lasāms",
    "Allow upload and editing" : "Atļaut augšupielādi un rediģēšanu",
    "File drop (upload only)" : "Datņu mešana (tikai augšupielādei)",
    "Read" : "Lasīt",
    "Upload" : "Augšupielādēt",
    "Edit" : "Rediģēt",
    "Allow creating" : "Atļaut veidošanu",
    "Allow deleting" : "Atļaut dzēšanu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Expiration date enforced" : "Piespiedu derīguma termiņš",
    "Set expiration date" : "Uzstādīt beigu termiņu",
    "Enter a date" : "Ievadiet datumu",
    "Note to recipient" : "Piezīme saņēmējam",
    "Unshare" : "Pārtraukt koplietošanu",
    "group" : "grupa",
    "conversation" : "saruna",
    "remote" : "attālināti",
    "remote group" : "attālinātā grupa",
    "guest" : "viesis",
    "Link copied" : "Saite nokopēta",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Only works for users with access to this file" : "Darbojas tikai lietotājiem, kuriem ir piekļuve šai datnei",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Cancel" : "Atcelt",
    "Hide download" : "Slēpt lejupielādi",
    "Password protect" : "Aizsargāt ar paroli",
    "Video verification" : "Video verifikācija",
    "Add another link" : "Pievienot citu saiti",
    "Share link" : "Koplietot saiti",
    "Resharing is not allowed" : "Atkārtota koplietošana nav atļauta",
    "Name or email …" : "Vārds vai e-pasts ...",
    "Name, email, or Federated Cloud ID …" : "Vārds, e-pasts vai federatīvā mākoņa ID ...",
    "Searching …" : "Meklē...",
    "No elements found." : "Elementi netika atrasti.",
    "Search globally" : "Meklēt globāli",
    "on {server}" : "uz {server}",
    "Others with access" : "Citi ar pieeju",
    "No other users with access found" : "Nav atrasti citi lietotāji ar pieeju",
    "Expires {relativetime}" : "Termiņš beidzas {relativetime}",
    "this share just expired." : "šai koplietošanai tikko beidzās termiņš.",
    "Shared with you by {owner}" : "{owner} koplietoja ar jums",
    "Link to a file" : "Datnes saite",
    "Shared" : "Koplietots",
    "Share" : "Koplietot",
    "Shared with" : "Koplietots ar",
    "Shared with you and the group {group} by {owner}" : "{owner} koplietoja ar jums un grupu {group}",
    "Shared with you and {circle} by {owner}" : "{owner} koplietoja ar jums un {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} koplietoja ar jums un sarunu {conversation}",
    "Shared with you in a conversation by {owner}" : " {owner} koplietoja ar jums sarunā",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Nosaukums",
    "Share time" : "Koplietošanas laiks",
    "Expiration date" : "Termiņa datums",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the item was removed" : "vienums tika dzēsts",
    "the link expired" : "saitei beidzies termiņš",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more info, please ask the person who sent this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Share note" : "Koplietot piezīmi",
    "Upload files to %s" : "Augšupielādēt datnes uz %s",
    "Note" : "Piezīme",
    "Select or drop files" : "Izvēlies vai ievelc datnes",
    "Uploading files" : "Augšupielādē datnes",
    "Uploaded files:" : "Augšupielādētas datnes:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Veicot datņu augšupielādi, jūs piekrītat %1$spakalpojuma noteikumiem%2$s.",
    "Add to your Nextcloud" : "Pievienot savam Nextcloud",
    "Wrong share ID, share doesn't exist" : "Nepareizs koplietošanas ID, koplietotne neeksistē",
    "Wrong path, file/folder doesn't exist" : "Nepareizs ceļš, datne/mape neeksistē",
    "Sorry, this link doesn’t seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "Toggle grid view" : "Pārslēgt režģa skatu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
